parse_source

Function parse_source 

pub fn parse_source(
    language: &str,
    uri: &str,
    source: &str,
) -> Option<ParsedDocument>
Parse source text without indexing it.

Canonical language tags are the tags returned by Lang::tag. PL/pgSQL is also accepted as a standalone embedded language.